(*
#****m* SecDec/loop/src/deco/decomposition.m
# NAME
#  decomposition.m
# USAGE
#  called from subdir/graph/graph.m, via decompose.pl
# PURPOSE
#  performs the primary and the iterated sector decomposition.
#  when infinite iteration is anticipated, a pre-decomposition
#  is performed using sdiQ to avoid this.
# RESULT
# [graph]sec*P*l*h*.out, graph*OUT.info written to subdir/graph, 
# SEE ALSO
#  primarySD.m, SDroutines.m, sdiQ.m
#****
*)

(* in Mathematica version >=8, decimal * 0 =0.(as decimal), whereas decimal * 0 = 0 (as
integer) for versions <8  *)

If[$VersionNumber>=8,                                                                                       
 Unprotect[MatchQ];                                                                                         
 MatchQ[aa_,0]:=MatchQ[N[aa],N[0]];                                                                         
 Protect[MatchQ]                                                                                            
];  

(*qlist is the list of sectors needing pre-decomposition to stop infinite recursion*)

(* does the actual sector decomposition *)

Get[StringJoin[path,ToString["src/deco/primarySD.m"]]];
Get[StringJoin[path,ToString["src/deco/SDroutines.m"]]];

mandmin=Table[Table[sp[i,j]->-sp[i,j],{j,i+1,externalegs}],{i,externalegs-1}]//Flatten;
extmassmin=Table[ssp[i]->-ssp[i],{i,externalegs}];
invarminusreps=Join[mandmin,extmassmin,{sp[i_,j_,k_]->-sp[i,j,k]}];
decotime=AbsoluteTiming[
FF[z]=(F[z]/.invarminusreps)//Expand;
NNu[z]=(Nu[z]/.invarminusreps)//Expand;
primlist=Complement[Table[np,{np,npmin,npmax,npstep}],qlist];
primseclist=primarysec[#,FF[z],Expand[U[z]],NNu[z],xl]&/@primlist;
If[MatchQ[qlist,{}]==False,
 Get[StringJoin[path,ToString["src/deco/sdiQ.m"]]];
 qprimseclist=primarysec[#,FF[z],Expand[U[z]],NNu[z],xl]&/@qlist;
 qseclist=(Sequence@@sdiQ[#])&/@qprimseclist;
 primseclist={Sequence@@qseclist,Sequence@@primseclist}
];

decomposedsectors=IteratedSD[primseclist];

(*decomposedsectors= primseclist;*)
makeoutput;
];

Print["\n"];
Print["Time taken to do the decomposition: ",decotime[[1]]," secs"];
