(*
  #****t* SecDec/loop/src/subexp/subandexpand.m
  #  NAME
  #    subandexpand.m
  #
  #  USAGE
  #  is used as a template for secdec/subdir/graph/subandexpand*l*h*.m
  #  These subandexpand*l*h* take the sector decomposed integrand, and runs the
  #  subtraction and epsilon expansion, then writes the f*.f files to be
  #  numerically integrated. 
  # 
  #  USES 
  #
  #  ${graph}sec*P*l*h*.out, formindlist.m, symbsub.m, ExpOpt.m, formfortran.m
  #
  #  USED BY 
  #    
  #  subexp.pl
  #
  #  PURPOSE
  #  to take the sector decomposition output, and produce f*.f (or with contour 
  #  deformation f*.cc and g*.cc) files for the numerical integration, for 
  #  Mathematica versions 7 and higher parallelization is used
  #    
  #  INPUTS
  #  
  #  inserted by subexp.pl:
  #  path: directory of secdec
  #  input decomposition: reads a list of files ${graph}sec*P*l*h*.out containing
  #  the output of the decomposition
  #  n: number of propagators
  #  logi: the number of logarithmic poles in this pole structure
  #  lini: the number of linear poles in this pole structure
  #  higheri: the number of higher order poles in this pole structure
  #  partsflag: whether IBP is to be used
  #  expu: exponent of U
  #  expf: minus the exponent of F in the decomposition - integrand is numerator*(U^expu)/(F^expf)
  #  precisionrequired: order of epsilon required for result
  #  diagramname: name of the diagram
  #  subdir: subdirectory where output is placed
  #  srcdir: directory of source code
  #
  #  variables:
  #  dieflag: is set to 1 by formindlist.m if there are no poles with this given structure
  #  time: time taken for this part of the calculation
  #    
  #  RESULT
  #  
  #  f*.f functions upto the required order are created in the appropriate directory
  #  
  #  SEE ALSO
  #  subexp.pl, formindlist.m, symbsub.m, formfortran.m
  #   
  #****
*)  

time=Timing[
Dim=;
outp=;
path=;
inputdecomposition
n=;
logi=;
lini=;
higheri=;
partsflag=;
language=;
extlegs=;
contourdef=;
xlambda=;
oscillatory=;
endpointflag=;

expu=//Simplify;
expf=//Simplify;
precisionrequired=;
diagramname=;
subdir=;
srcdir=;

individual sector

polestring=StringJoin[ToString[logi],"l",ToString[lini],"h",ToString[higheri]];

$HistoryLength=0;
Get[StringJoin[path,srcdir,"formindlist.m"]]; (*forms integrandfunctionlist, together with fstore,ustore,nstore and degen*)
If[
   dieflag==0
   ,
   If[NumberQ[indsec],polestring=StringJoin["sec",ToString[indsec],"P",polestring]];
   (*performs the symbolic subtraction:*) 
   Get[StringJoin[path,srcdir,"symbsub.m"]]; 
   (*routines necessary for optimisation + fortranisation:*)
   If[$VersionNumber>=7,Get[StringJoin[path,srcdir,"ExpOptP.m"]],Get[StringJoin[path,srcdir,"ExpOpt.m"]]]; 
   If[contourdef,
      If[$VersionNumber>=7,Get[StringJoin[path,srcdir,"formContourPC.m"]],Get[StringJoin[path,srcdir,"formContourC.m"]]]
      , (* else no contour deformation *)
      If[MatchQ[language,Cpp],
	 If[$VersionNumber>=7,Get[StringJoin[path,srcdir,"formPC.m"]],Get[StringJoin[path,srcdir,"formC.m"]]]
	 ,
	 If[$VersionNumber>=7,Get[StringJoin[path,srcdir,"formPfortran.m"]],Get[StringJoin[path,srcdir,"formfortran.m"]]];
	 ] (* end if language=C *)
      ] (* end if contourdef *)
   ,
   Print["no poles of this type"]
   ];
	    ][[1]];
If[Or[MatchQ[language,Cpp],contourdef],langstring="C++",langstring="fortran"];
Print["Total time taken to produce "<>langstring<>" files: ",time," secs"];


